@@ -103,7 +103,7 @@ int main(int argc, char *argv[])
     if (loginUidFile.open(QIODevice::ReadOnly)) {
         QString loginUid = QString(loginUidFile.readAll()).trimmed();
         loginUidFile.close();
-        if (loginUid == "0") {
+        if (loginUid == QLatin1String("0")) {
             QMessageBox::critical(
                 nullptr, QObject::tr("Error"),
                 QObject::tr(
